@@ -46,11 +46,11 @@ App::CELL::Guide - Introduction to App::CELL (POD-only module)
 
 =head1 VERSION
 
-Version 0.228
+Version 0.230
 
 =cut
 
-our $VERSION = '0.228';
+our $VERSION = '0.230';
 
 
 
@@ -523,7 +523,7 @@ It is also possible to report the caller's filename and line number:
     App::CELL::Status->new( level => 'ERR', 
                            code => 'CODE1',
                            args => [ 'foo', 'bar' ],
-                           caller => [ caller ],
+                           caller => [ CORE::caller() ],
                          );
 
 It is also possible to pass a message object in lieu of C<code> and
